==> crealand-1.0.23.tar.gz: crealand-1.0.23/crealand/__init__.py <==
__version__ = '1.0.23'

from ._apis import (
    ai as AI, 
    detect as Detect, 
    event as Event, 
    interactive as Interactive, 
    object as Object
)

from ._apis.constants import (
    KeyboardType, 
    KeyActiveType, 
    KeyboardActiveType, 
    MouseKeyType, 
    HangPointType, 
    Actions, 
    Axis, 
    AxisType, 
    Tone, 
    Volume, 
    OptionName, 
    ResultType, 
    ToastPosition, 
    ToastState, 
    Direction,  
    FilterStyle, 
    ActionType
)

from ._apis.interactive import (
    Dialogue, 
    HelpPanel, 
    TaskPanel, 
    Speak, 
    Interactive
)

from ._apis.media import (
    Sound, 
    Video, 
    Image
)

from ._apis.sensor import (
    Ultrasonic, 
    Auditory, 
    Visual, 
    Temperature, 
    Humidity, 
    Gravity
)

from ._utils.logger_setup import (
    enable_logger, 
    disable_logger, 
    setup_logger
)

def __initialize():
    try:
        import os
        import threading
        from ._core.websocket.websocket_client import ws_connect, get_ws_client, init_callback

        logger = setup_logger()
        server_url = os.getenv('ENV_CREALAND_UCODELINK_SERVER_URL')
        session_id = os.getenv('ENV_CREALAND_SESSIONID')
        logger.info(f'server_url: {server_url}, session_id: {session_id}')
        #taskId = os.getenv('ENV_CREALAND_TASKID')
        threading.Thread(target=ws_connect, args=(server_url, session_id, )).start()
        while True:
            ws_client = get_ws_client()
            if (ws_client and ws_client.websocket and 
                ws_client.connected and ws_client.session_id):
                break
        init_callback()
    except Exception as e:
        logger.error(f'An error occurred: {e}')

__initialize()

==> crealand-1.0.29.tar.gz: crealand-1.0.29/crealand/__init__.py <==
__version__ = '1.0.29'

from ._apis import (
    ai as AI, 
    detect as Detect, 
    event as Event, 
    interactive as Interactive, 
    object as Object
)

from ._apis.constants import (
    KeyboardType, 
    KeyActiveType, 
    KeyboardActiveType, 
    MouseKeyType, 
    HangPointType, 
    Actions, 
    Axis, 
    AxisType, 
    Tone, 
    Volume, 
    OptionName, 
    ResultType, 
    ToastPosition, 
    ToastState, 
    Direction,  
    FilterStyle, 
    ActionType
)

from ._apis.interactive import (
    Dialogue, 
    HelpPanel, 
    TaskPanel, 
    Speak, 
    Interactive
)

from ._apis.media import (
    Sound, 
    Video, 
    Image
)

from ._apis.sensor import (
    Ultrasonic, 
    Auditory, 
    Visual, 
    Temperature, 
    Humidity, 
    Gravity
)

from ._utils._logger_setup import (
    enable_logger, 
    disable_logger, 
    setup_logger
)

def __initialize():
    try:
        import os
        import time
        import threading
        from ._core.websocket.websocket_client import ws_connect, get_ws_client, init_callback

        logger = setup_logger()
        server_url = os.getenv('ENV_CREALAND_UCODELINK_SERVER_URL')
        session_id = os.getenv('ENV_CREALAND_SESSIONID')
        logger.info(f'server_url: {server_url}, session_id: {session_id}')
        #taskId = os.getenv('ENV_CREALAND_TASKID')
        threading.Thread(target=ws_connect, args=(server_url, session_id, )).start()
        while True:
            time.sleep(0.1)
            ws_client = get_ws_client()
            if (ws_client and ws_client.websocket and 
                ws_client.connected and ws_client.session_id):
                break
        init_callback()
    except Exception as e:
        logger.error(f'An error occurred: {e}')

__initialize()
